@@ -55,7 +55,7 @@ plot1D <- function( ans,
                     main = "default",
                     abs = TRUE)
 {
-  if(class(ans)!="mrs")
+  !is(ans,"mrs")
   {
     print("ERROR: ans should be an MRS object.")
     return(0)
@@ -149,4 +149,4 @@ plot1D <- function( ans,
   par(.pardefault)   
   
   
-}
\ No newline at end of file
+}
