@@ -69,7 +69,7 @@ plot2D = function(  ans,
                     main = "default",
                     abs = TRUE ) 
 { 
-  if(class(ans)!="mrs")
+  !is(ans,"mrs")
   {
     print("ERROR: ans should be an mrs object.")
     return(0)
@@ -252,4 +252,4 @@ plot2D = function(  ans,
     
   }
   par(.pardefault)   
-}
\ No newline at end of file
+}
